**My First Pakage**

A simple python package for learning purposes

**Installation**

```python
pip install nir-my-pakage
```

Usage

```
from nir_my_pakage import greet, addition_numbers
print(greet("Nazmul"))
print(addition_numbers(2,2))
```
